==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/SubscriberSpecBuilder.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriberSpecBuilder extends SubscriberSpecFluentImpl<SubscriberSpecBuilder> implements VisitableBuilder<SubscriberSpec,SubscriberSpecBuilder> {

    SubscriberSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriberSpecBuilder() { 
        this(true);
    }


    public SubscriberSpecBuilder(Boolean validationEnabled) { 
        this(new SubscriberSpec(), validationEnabled);
    }


    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SubscriberSpec(), validationEnabled);
    }


    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,SubscriberSpec instance) { 
        this(fluent, instance, true);
    }


    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,SubscriberSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withGeneration(instance.getGeneration()); 
        fluent.withReplyUri(instance.getReplyUri()); 
        fluent.withSubscriberUri(instance.getSubscriberUri()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriberSpecBuilder(SubscriberSpec instance) { 
        this(instance,true);
    }


    public SubscriberSpecBuilder(SubscriberSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withDelivery(instance.getDelivery()); 
        this.withGeneration(instance.getGeneration()); 
        this.withReplyUri(instance.getReplyUri()); 
        this.withSubscriberUri(instance.getSubscriberUri()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriberSpec build() {
        SubscriberSpec buildable = new SubscriberSpec(fluent.getDelivery(),fluent.getGeneration(),fluent.getReplyUri(),fluent.getSubscriberUri(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriberSpecBuilder that = (SubscriberSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/SubscriberSpecBuilder.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriberSpecBuilder extends SubscriberSpecFluentImpl<SubscriberSpecBuilder> implements VisitableBuilder<SubscriberSpec,SubscriberSpecBuilder> {

    SubscriberSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriberSpecBuilder() {
        this(true);
    }

    public SubscriberSpecBuilder(Boolean validationEnabled) {
        this(new SubscriberSpec(), validationEnabled);
    }

    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SubscriberSpec(), validationEnabled);
    }

    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,SubscriberSpec instance) {
        this(fluent, instance, true);
    }

    public SubscriberSpecBuilder(SubscriberSpecFluent<?> fluent,SubscriberSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withGeneration(instance.getGeneration()); 
        fluent.withReplyUri(instance.getReplyUri()); 
        fluent.withSubscriberUri(instance.getSubscriberUri()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public SubscriberSpecBuilder(SubscriberSpec instance) {
        this(instance,true);
    }

    public SubscriberSpecBuilder(SubscriberSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDelivery(instance.getDelivery()); 
        this.withGeneration(instance.getGeneration()); 
        this.withReplyUri(instance.getReplyUri()); 
        this.withSubscriberUri(instance.getSubscriberUri()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.EditableSubscriberSpec build() {
        EditableSubscriberSpec buildable = new EditableSubscriberSpec(fluent.getDelivery(),fluent.getGeneration(),fluent.getReplyUri(),fluent.getSubscriberUri(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriberSpecBuilder that = (SubscriberSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
